@@ -4,9 +4,15 @@ import functools
 from typing import TYPE_CHECKING, Any, Dict, Optional
 
 from azure.identity import ClientSecretCredential, DefaultAzureCredential
+from azure.identity.aio import DefaultAzureCredential as ADefaultAzureCredential
 from azure.mgmt.containerinstance import ContainerInstanceManagementClient
 from azure.mgmt.resource import ResourceManagementClient
-from pydantic import Field, SecretStr, root_validator
+from pydantic import VERSION as PYDANTIC_VERSION
+
+if PYDANTIC_VERSION.startswith("2."):
+    from pydantic.v1 import Field, SecretStr, root_validator
+else:
+    from pydantic import Field, SecretStr, root_validator
 
 try:
     from azure.cosmos import CosmosClient
@@ -72,18 +78,23 @@ def _raise_help_msg(key: str):
 
 class AzureBlobStorageCredentials(Block):
     """
-    Block used to manage Blob Storage authentication with Azure.
-    Azure authentication is handled via the `azure` module through
-    a connection string.
+    Stores credentials for authenticating with Azure Blob Storage.
 
     Args:
-        connection_string: Includes the authorization information required.
+        account_url: The URL for your Azure storage account. If provided, the account
+            URL will be used to authenticate with the discovered default Azure
+            credentials.
+        connection_string: The connection string to your Azure storage account. If
+            provided, the connection string will take precedence over the account URL.
 
     Example:
-        Load stored Azure Blob Storage credentials:
+        Load stored Azure Blob Storage credentials and retrieve a blob service client:
         ```python
         from prefect_azure import AzureBlobStorageCredentials
+
         azure_credentials_block = AzureBlobStorageCredentials.load("BLOCK_NAME")
+
+        blob_service_client = azure_credentials_block.get_blob_client()
         ```
     """
 
@@ -94,15 +105,17 @@ class AzureBlobStorageCredentials(Block):
     connection_string: Optional[SecretStr] = Field(
         default=None,
         description=(
-            "If account_url is not provided, " "the connection string to authenticate."
+            "The connection string to your Azure storage account. If provided, the "
+            "connection string will take precedence over the account URL."
         ),
     )
     account_url: Optional[str] = Field(
         default=None,
+        title="Account URL",
         description=(
-            "If a connection string is not provided, "
-            "the URL to the Blob Storage account; will use "
-            "DefaultAzureCredential to authenticate."
+            "The URL for your Azure storage account. If provided, the account "
+            "URL will be used to authenticate with the discovered default "
+            "Azure credentials."
         ),
     )
 
@@ -151,7 +164,7 @@ class AzureBlobStorageCredentials(Block):
         if self.connection_string is None:
             return BlobServiceClient(
                 account_url=self.account_url,
-                credential=DefaultAzureCredential(),
+                credential=ADefaultAzureCredential(),
             )
 
         return BlobServiceClient.from_connection_string(
@@ -195,7 +208,7 @@ class AzureBlobStorageCredentials(Block):
             return BlobClient(
                 account_url=self.account_url,
                 container_name=container,
-                credential=DefaultAzureCredential(),
+                credential=ADefaultAzureCredential(),
                 blob_name=blob,
             )
 
@@ -240,7 +253,7 @@ class AzureBlobStorageCredentials(Block):
             return ContainerClient(
                 account_url=self.account_url,
                 container_name=container,
-                credential=DefaultAzureCredential(),
+                credential=ADefaultAzureCredential(),
             )
 
         container_client = ContainerClient.from_connection_string(
@@ -401,7 +414,8 @@ class AzureMlCredentials(Block):
         default=..., description="The service principal password/key."
     )
     subscription_id: str = Field(
-        default=..., description="The Azure subscription ID containing the workspace."
+        default=...,
+        description="The Azure subscription ID containing the workspace, in format: '00000000-0000-0000-0000-000000000000'.",  # noqa
     )
     resource_group: str = Field(
         default=..., description="The resource group containing the workspace."
